from enum import Enum


class EventCode(Enum):

    LEAVE = 1
    JOIN_FINISHED = 2
    MOVE = 3
    TELEPORT = 4
    CHANGE_EQUIPMENT = 5
    HEALTH_UPDATE = 6
    HEALTH_UPDATES = 7
    ENERGY_UPDATE = 8
    DAMAGE_SHIELD_UPDATE = 9
    CRAFTING_FOCUS_UPDATE = 10
    ACTIVE_SPELL_EFFECTS_UPDATE = 11
    RESET_COOLDOWNS = 12
    ATTACK = 13
    CAST_START = 14
    CHANNELING_UPDATE = 15
    CAST_CANCEL = 16
    CAST_TIME_UPDATE = 17
    CAST_FINISHED = 18
    CAST_SPELL = 19
    CAST_SPELLS = 20
    CAST_HIT = 21
    CAST_HITS = 22
    STORED_TARGETS_UPDATE = 23
    CHANNELING_ENDED = 24
    ATTACK_BUILDING = 25
    INVENTORY_PUT_ITEM = 26
    INVENTORY_DELETE_ITEM = 27
    INVENTORY_STATE = 28
    NEW_CHARACTER = 29
    NEW_EQUIPMENT_ITEM = 30
    NEW_SIEGE_BANNER_ITEM = 31
    NEW_SIMPLE_ITEM = 32
    NEW_FURNITURE_ITEM = 33
    NEW_KILL_TROPHY_ITEM = 34
    NEW_JOURNAL_ITEM = 35
    NEW_LABORER_ITEM = 36
    NEW_EQUIPMENT_ITEM_LEGENDARY_SOUL = 37
    NEW_SIMPLE_HARVESTABLE_OBJECT = 38
    NEW_SIMPLE_HARVESTABLE_OBJECT_LIST = 39
    NEW_HARVESTABLE_OBJECT = 40
    NEW_TREASURE_DESTINATION_OBJECT = 41
    TREASURE_DESTINATION_OBJECT_STATUS = 42
    CLOSE_TREASURE_DESTINATION_OBJECT = 43
    NEW_SILVER_OBJECT = 44
    NEW_BUILDING = 45
    HARVESTABLE_CHANGE_STATE = 46
    MOB_CHANGE_STATE = 47
    FACTION_BUILDING_INFO = 48
    CRAFT_BUILDING_INFO = 49
    REPAIR_BUILDING_INFO = 50
    MELD_BUILDING_INFO = 51
    CONSTRUCTION_SITE_INFO = 52
    PLAYER_BUILDING_INFO = 53
    FARM_BUILDING_INFO = 54
    TUTORIAL_BUILDING_INFO = 55
    LABORER_OBJECT_INFO = 56
    LABORER_OBJECT_JOB_INFO = 57
    MARKET_PLACE_BUILDING_INFO = 58
    HARVEST_START = 59
    HARVEST_CANCEL = 60
    HARVEST_FINISHED = 61
    TAKE_SILVER = 62
    REMOVE_SILVER = 63
    ACTION_ON_BUILDING_START = 64
    ACTION_ON_BUILDING_CANCEL = 65
    ACTION_ON_BUILDING_FINISHED = 66
    ITEM_REROLL_QUALITY_FINISHED = 67
    INSTALL_RESOURCE_START = 68
    INSTALL_RESOURCE_CANCEL = 69
    INSTALL_RESOURCE_FINISHED = 70
    CRAFT_ITEM_FINISHED = 71
    LOGOUT_CANCEL = 72
    CHAT_MESSAGE = 73
    CHAT_SAY = 74
    CHAT_WHISPER = 75
    CHAT_MUTED = 76
    PLAY_EMOTE = 77
    STOP_EMOTE = 78
    SYSTEM_MESSAGE = 79
    UTILITY_TEXT_MESSAGE = 80
    UPDATE_MONEY = 81
    UPDATE_FAME = 82
    UPDATE_LEARNING_POINTS = 83
    UPDATE_RE_SPEC_POINTS = 84
    UPDATE_CURRENCY = 85
    UPDATE_FACTION_STANDING = 86
    UPDATE_MIST_CITY_STANDING = 87
    RESPAWN = 88
    SERVER_DEBUG_LOG = 89
    CHARACTER_EQUIPMENT_CHANGED = 90
    REGENERATION_HEALTH_CHANGED = 91
    REGENERATION_ENERGY_CHANGED = 92
    REGENERATION_MOUNT_HEALTH_CHANGED = 93
    REGENERATION_CRAFTING_CHANGED = 94
    REGENERATION_HEALTH_ENERGY_COMBO_CHANGED = 95
    REGENERATION_PLAYER_COMBO_CHANGED = 96
    DURABILITY_CHANGED = 97
    NEW_LOOT = 98
    ATTACH_ITEM_CONTAINER = 99
    DETACH_ITEM_CONTAINER = 100
    INVALIDATE_ITEM_CONTAINER = 101
    LOCK_ITEM_CONTAINER = 102
    GUILD_UPDATE = 103
    GUILD_PLAYER_UPDATED = 104
    INVITED_TO_GUILD = 105
    GUILD_MEMBER_WORLD_UPDATE = 106
    UPDATE_MATCH_DETAILS = 107
    OBJECT_EVENT = 108
    NEW_MONOLITH_OBJECT = 109
    MONOLITH_HAS_BANNERS_PLACED_UPDATE = 110
    NEW_ORB_OBJECT = 111
    NEW_CASTLE_OBJECT = 112
    NEW_SPELL_EFFECT_AREA = 113
    UPDATE_SPELL_EFFECT_AREA = 114
    NEW_CHAIN_SPELL = 115
    UPDATE_CHAIN_SPELL = 116
    NEW_TREASURE_CHEST = 117
    START_MATCH = 118
    START_ARENA_MATCH_INFOS = 119
    END_ARENA_MATCH = 120
    MATCH_UPDATE = 121
    ACTIVE_MATCH_UPDATE = 122
    NEW_MOB = 123
    DEBUG_MOB_INFO = 124
    DEBUG_VARIABLES_INFO = 125
    DEBUG_REPUTATION_INFO = 126
    DEBUG_DIMINISHING_RETURN_INFO = 127
    DEBUG_SMART_CLUSTER_QUEUE_INFO = 128
    CLAIM_ORB_START = 129
    CLAIM_ORB_FINISHED = 130
    CLAIM_ORB_CANCEL = 131
    ORB_UPDATE = 132
    ORB_CLAIMED = 133
    ORB_RESET = 134
    NEW_WAR_CAMP_OBJECT = 135
    NEW_MATCH_LOOT_CHEST_OBJECT = 136
    NEW_ARENA_EXIT = 137
    GUILD_MEMBER_TERRITORY_UPDATE = 138
    INVITED_MERCENARY_TO_MATCH = 139
    CLUSTER_INFO_UPDATE = 140
    FORCED_MOVEMENT = 141
    FORCED_MOVEMENT_CANCEL = 142
    CHARACTER_STATS = 143
    CHARACTER_STATS_KILL_HISTORY = 144
    CHARACTER_STATS_DEATH_HISTORY = 145
    GUILD_STATS = 146
    KILL_HISTORY_DETAILS = 147
    FULL_ACHIEVEMENT_INFO = 148
    FINISHED_ACHIEVEMENT = 149
    ACHIEVEMENT_PROGRESS_INFO = 150
    FULL_ACHIEVEMENT_PROGRESS_INFO = 151
    FULL_TRACKED_ACHIEVEMENT_INFO = 152
    FULL_AUTO_LEARN_ACHIEVEMENT_INFO = 153
    QUEST_GIVER_QUEST_OFFERED = 154
    QUEST_GIVER_DEBUG_INFO = 155
    CONSOLE_EVENT = 156
    TIME_SYNC = 157
    CHANGE_AVATAR = 158
    CHANGE_MOUNT_SKIN = 159
    GAME_EVENT = 160
    KILLED_PLAYER = 161
    DIED = 162
    KNOCKED_DOWN = 163
    UNCONCIOUS = 164
    MATCH_PLAYER_JOINED_EVENT = 165
    MATCH_PLAYER_STATS_EVENT = 166
    MATCH_PLAYER_STATS_COMPLETE_EVENT = 167
    MATCH_TIME_LINE_EVENT_EVENT = 168
    MATCH_PLAYER_MAIN_GEAR_STATS_EVENT = 169
    MATCH_PLAYER_CHANGED_AVATAR_EVENT = 170
    INVITATION_PLAYER_TRADE = 171
    PLAYER_TRADE_START = 172
    PLAYER_TRADE_CANCEL = 173
    PLAYER_TRADE_UPDATE = 174
    PLAYER_TRADE_FINISHED = 175
    PLAYER_TRADE_ACCEPT_CHANGE = 176
    MINI_MAP_PING = 177
    MARKET_PLACE_NOTIFICATION = 178
    DUELLING_CHALLENGE_PLAYER = 179
    NEW_DUELLING_POST = 180
    DUEL_STARTED = 181
    DUEL_ENDED = 182
    DUEL_DENIED = 183
    DUEL_REQUEST_CANCELED = 184
    DUEL_LEFT_AREA = 185
    DUEL_RE_ENTERED_AREA = 186
    NEW_REAL_ESTATE = 187
    MINI_MAP_OWNED_BUILDINGS_POSITIONS = 188
    REAL_ESTATE_LIST_UPDATE = 189
    GUILD_LOGO_UPDATE = 190
    GUILD_LOGO_CHANGED = 191
    PLACEABLE_OBJECT_PLACE = 192
    PLACEABLE_OBJECT_PLACE_CANCEL = 193
    FURNITURE_OBJECT_BUFF_PROVIDER_INFO = 194
    FURNITURE_OBJECT_CHEAT_PROVIDER_INFO = 195
    FARMABLE_OBJECT_INFO = 196
    NEW_UNREAD_MAILS = 197
    MAIL_OPERATION_POSSIBLE = 198
    GUILD_LOGO_OBJECT_UPDATE = 199
    START_LOGOUT = 200
    NEW_CHAT_CHANNELS = 201
    JOINED_CHAT_CHANNEL = 202
    LEFT_CHAT_CHANNEL = 203
    REMOVED_CHAT_CHANNEL = 204
    ACCESS_STATUS = 205
    MOUNTED = 206
    MOUNT_START = 207
    MOUNT_CANCEL = 208
    NEW_TRAVELPOINT = 209
    NEW_ISLAND_ACCESS_POINT = 210
    NEW_EXIT = 211
    UPDATE_HOME = 212
    UPDATE_CHAT_SETTINGS = 213
    RESURRECTION_OFFER = 214
    RESURRECTION_REPLY = 215
    LOOT_EQUIPMENT_CHANGED = 216
    UPDATE_UNLOCKED_GUILD_LOGOS = 217
    UPDATE_UNLOCKED_AVATARS = 218
    UPDATE_UNLOCKED_AVATAR_RINGS = 219
    UPDATE_UNLOCKED_BUILDINGS = 220
    NEW_ISLAND_MANAGEMENT = 221
    NEW_TELEPORT_STONE = 222
    CLOAK = 223
    PARTY_INVITATION = 224
    PARTY_JOIN_REQUEST = 225
    PARTY_JOINED = 226
    PARTY_DISBANDED = 227
    PARTY_PLAYER_JOINED = 228
    PARTY_CHANGED_ORDER = 229
    PARTY_PLAYER_LEFT = 230
    PARTY_LEADER_CHANGED = 231
    PARTY_LOOT_SETTING_CHANGED_PLAYER = 232
    PARTY_SILVER_GAINED = 233
    PARTY_PLAYER_UPDATED = 234
    PARTY_INVITATION_ANSWER = 235
    PARTY_JOIN_REQUEST_ANSWER = 236
    PARTY_MARKED_OBJECTS_UPDATED = 237
    PARTY_ON_CLUSTER_PARTY_JOINED = 238
    PARTY_SET_ROLE_FLAG = 239
    PARTY_INVITE_OR_JOIN_PLAYER_EQUIPMENT_INFO = 240
    PARTY_READY_CHECK_UPDATE = 241
    SPELL_COOLDOWN_UPDATE = 242
    NEW_HELLGATE_EXIT_PORTAL = 243
    NEW_EXPEDITION_EXIT = 244
    NEW_EXPEDITION_NARRATOR = 245
    EXIT_ENTER_START = 246
    EXIT_ENTER_CANCEL = 247
    EXIT_ENTER_FINISHED = 248
    NEW_QUEST_GIVER_OBJECT = 249
    FULL_QUEST_INFO = 250
    QUEST_PROGRESS_INFO = 251
    QUEST_GIVER_INFO_FOR_PLAYER = 252
    FULL_EXPEDITION_INFO = 253
    EXPEDITION_QUEST_PROGRESS_INFO = 254
    INVITED_TO_EXPEDITION = 255
    EXPEDITION_REGISTRATION_INFO = 256
    ENTERING_EXPEDITION_START = 257
    ENTERING_EXPEDITION_CANCEL = 258
    REWARD_GRANTED = 259
    ARENA_REGISTRATION_INFO = 260
    ENTERING_ARENA_START = 261
    ENTERING_ARENA_CANCEL = 262
    ENTERING_ARENA_LOCK_START = 263
    ENTERING_ARENA_LOCK_CANCEL = 264
    INVITED_TO_ARENA_MATCH = 265
    USING_HELLGATE_SHRINE = 266
    ENTERING_HELLGATE_LOCK_START = 267
    ENTERING_HELLGATE_LOCK_CANCEL = 268
    PLAYER_COUNTS = 269
    IN_COMBAT_STATE_UPDATE = 270
    OTHER_GRABBED_LOOT = 271
    TREASURE_CHEST_USING_START = 272
    TREASURE_CHEST_USING_FINISHED = 273
    TREASURE_CHEST_USING_CANCEL = 274
    TREASURE_CHEST_USING_OPENING_COMPLETE = 275
    TREASURE_CHEST_FORCE_CLOSE_INVENTORY = 276
    LOCAL_TREASURES_UPDATE = 277
    LOOT_CHEST_SPAWNPOINTS_UPDATE = 278
    PREMIUM_CHANGED = 279
    PREMIUM_EXTENDED = 280
    PREMIUM_LIFE_TIME_REWARD_GAINED = 281
    GOLD_PURCHASED = 282
    LABORER_GOT_UPGRADED = 283
    JOURNAL_GOT_FULL = 284
    JOURNAL_FILL_ERROR = 285
    FRIEND_REQUEST = 286
    FRIEND_REQUEST_INFOS = 287
    FRIEND_INFOS = 288
    FRIEND_REQUEST_ANSWERED = 289
    FRIEND_ONLINE_STATUS = 290
    FRIEND_REQUEST_CANCELED = 291
    FRIEND_REMOVED = 292
    FRIEND_UPDATED = 293
    PARTY_LOOT_ITEMS = 294
    PARTY_LOOT_ITEMS_REMOVED = 295
    REPUTATION_UPDATE = 296
    DEFENSE_UNIT_ATTACK_BEGIN = 297
    DEFENSE_UNIT_ATTACK_END = 298
    DEFENSE_UNIT_ATTACK_DAMAGE = 299
    UNRESTRICTED_PVP_ZONE_UPDATE = 300
    REPUTATION_IMPLICATION_UPDATE = 301
    NEW_MOUNT_OBJECT = 302
    MOUNT_HEALTH_UPDATE = 303
    MOUNT_COOLDOWN_UPDATE = 304
    NEW_EXPEDITION_AGENT = 305
    NEW_EXPEDITION_CHECK_POINT = 306
    EXPEDITION_START_EVENT = 307
    VOTE_EVENT = 308
    RATING_EVENT = 309
    NEW_ARENA_AGENT = 310
    BOOST_FARMABLE = 311
    USE_FUNCTION = 312
    NEW_PORTAL_ENTRANCE = 313
    NEW_PORTAL_EXIT = 314
    NEW_RANDOM_DUNGEON_EXIT = 315
    WAITING_QUEUE_UPDATE = 316
    PLAYER_MOVEMENT_RATE_UPDATE = 317
    OBSERVE_START = 318
    MINIMAP_ZERGS = 319
    MINIMAP_SMART_CLUSTER_ZERGS = 320
    PAYMENT_TRANSACTIONS = 321
    PERFORMANCE_STATS_UPDATE = 322
    OVERLOAD_MODE_UPDATE = 323
    DEBUG_DRAW_EVENT = 324
    RECORD_CAMERA_MOVE = 325
    RECORD_START = 326
    DELIVER_CARRIABLE_OBJECT_START = 327
    DELIVER_CARRIABLE_OBJECT_CANCEL = 328
    DELIVER_CARRIABLE_OBJECT_RESET = 329
    DELIVER_CARRIABLE_OBJECT_FINISHED = 330
    TERRITORY_CLAIM_START = 331
    TERRITORY_CLAIM_CANCEL = 332
    TERRITORY_CLAIM_FINISHED = 333
    TERRITORY_SCHEDULE_RESULT = 334
    TERRITORY_UPGRADE_WITH_POWER_CRYSTAL_RESULT = 335
    RECEIVE_CARRIABLE_OBJECT_START = 336
    RECEIVE_CARRIABLE_OBJECT_FINISHED = 337
    UPDATE_ACCOUNT_STATE = 338
    START_DETERMINISTIC_ROAM = 339
    GUILD_FULL_ACCESS_TAGS_UPDATED = 340
    GUILD_ACCESS_TAG_UPDATED = 341
    GVG_SEASON_UPDATE = 342
    GVG_SEASON_CHEAT_COMMAND = 343
    SEASON_POINTS_BY_KILLING_BOOSTER = 344
    FISHING_START = 345
    FISHING_CAST = 346
    FISHING_CATCH = 347
    FISHING_FINISHED = 348
    FISHING_CANCEL = 349
    NEW_FLOAT_OBJECT = 350
    NEW_FISHING_ZONE_OBJECT = 351
    FISHING_MINI_GAME = 352
    ALBION_JOURNAL_ACHIEVEMENT_COMPLETED = 353
    UPDATE_PUPPET = 354
    CHANGE_FLAGGING_FINISHED = 355
    NEW_OUTPOST_OBJECT = 356
    OUTPOST_UPDATE = 357
    OUTPOST_CLAIMED = 358
    OVER_CHARGE_END = 359
    OVER_CHARGE_STATUS = 360
    PARTY_FINDER_FULL_UPDATE = 361
    PARTY_FINDER_UPDATE = 362
    PARTY_FINDER_APPLICANTS_UPDATE = 363
    PARTY_FINDER_EQUIPMENT_SNAPSHOT = 364
    PARTY_FINDER_JOIN_REQUEST_DECLINED = 365
    NEW_UNLOCKED_PERSONAL_SEASON_REWARDS = 366
    PERSONAL_SEASON_POINTS_GAINED = 367
    PERSONAL_SEASON_PAST_SEASON_DATA_EVENT = 368
    EASY_ANTI_CHEAT_MESSAGE_TO_CLIENT = 369
    MATCH_LOOT_CHEST_OPENING_START = 370
    MATCH_LOOT_CHEST_OPENING_FINISHED = 371
    MATCH_LOOT_CHEST_OPENING_CANCEL = 372
    NOTIFY_CRYSTAL_MATCH_REWARD = 373
    CRYSTAL_REALM_FEEDBACK = 374
    NEW_LOCATION_MARKER = 375
    NEW_TUTORIAL_BLOCKER = 376
    NEW_TILE_SWITCH = 377
    NEW_INFORMATION_PROVIDER = 378
    NEW_DYNAMIC_GUILD_LOGO = 379
    NEW_DECORATION = 380
    TUTORIAL_UPDATE = 381
    TRIGGER_HINT_BOX = 382
    RANDOM_DUNGEON_POSITION_INFO = 383
    NEW_LOOT_CHEST = 384
    UPDATE_LOOT_CHEST = 385
    LOOT_CHEST_OPENED = 386
    UPDATE_LOOT_PROTECTED_BY_MOBS_WITH_MINIMAP_DISPLAY = 387
    NEW_SHRINE = 388
    UPDATE_SHRINE = 389
    UPDATE_ROOM = 390
    NEW_MIST_DUNGEON_ROOM_MOB_SOUL = 391
    NEW_HELLGATE_SHRINE = 392
    UPDATE_HELLGATE_SHRINE = 393
    ACTIVATE_HELLGATE_EXIT = 394
    MUTE_PLAYER_UPDATE = 395
    SHOP_TILE_UPDATE = 396
    SHOP_UPDATE = 397
    ANTI_CHEAT_KICK = 398
    BATTL_EYE_SERVER_MESSAGE = 399
    UNLOCK_VANITY_UNLOCK = 400
    AVATAR_UNLOCKED = 401
    CUSTOMIZATION_CHANGED = 402
    BASE_VAULT_INFO = 403
    GUILD_VAULT_INFO = 404
    BANK_VAULT_INFO = 405
    RECOVERY_VAULT_PLAYER_INFO = 406
    RECOVERY_VAULT_GUILD_INFO = 407
    UPDATE_WARDROBE = 408
    CASTLE_PHASE_CHANGED = 409
    GUILD_ACCOUNT_LOG_EVENT = 410
    NEW_HIDEOUT_OBJECT = 411
    NEW_HIDEOUT_MANAGEMENT = 412
    NEW_HIDEOUT_EXIT = 413
    INIT_HIDEOUT_ATTACK_START = 414
    INIT_HIDEOUT_ATTACK_CANCEL = 415
    INIT_HIDEOUT_ATTACK_FINISHED = 416
    HIDEOUT_MANAGEMENT_UPDATE = 417
    HIDEOUT_UPGRADE_WITH_POWER_CRYSTAL_RESULT = 418
    IP_CHANGED = 419
    SMART_CLUSTER_QUEUE_UPDATE_INFO = 420
    SMART_CLUSTER_QUEUE_ACTIVE_INFO = 421
    SMART_CLUSTER_QUEUE_KICK_WARNING = 422
    SMART_CLUSTER_QUEUE_INVITE = 423
    RECEIVED_GVG_SEASON_POINTS = 424
    TOWER_POWER_POINT_UPDATE = 425
    OPEN_WORLD_ATTACK_SCHEDULE_START = 426
    OPEN_WORLD_ATTACK_SCHEDULE_FINISHED = 427
    OPEN_WORLD_ATTACK_SCHEDULE_CANCEL = 428
    OPEN_WORLD_ATTACK_CONQUER_START = 429
    OPEN_WORLD_ATTACK_CONQUER_FINISHED = 430
    OPEN_WORLD_ATTACK_CONQUER_CANCEL = 431
    OPEN_WORLD_ATTACK_CONQUER_STATUS = 432
    OPEN_WORLD_ATTACK_START = 433
    OPEN_WORLD_ATTACK_END = 434
    NEW_RANDOM_RESOURCE_BLOCKER = 435
    NEW_HOME_OBJECT = 436
    HIDEOUT_OBJECT_UPDATE = 437
    UPDATE_INFAMY = 438
    MINIMAP_POSITION_MARKERS = 439
    NEW_TUNNEL_EXIT = 440
    CORRUPTED_DUNGEON_UPDATE = 441
    CORRUPTED_DUNGEON_STATUS = 442
    CORRUPTED_DUNGEON_INFAMY = 443
    HELLGATE_RESTRICTED_AREA_UPDATE = 444
    HELLGATE_INFAMY = 445
    HELLGATE_STATUS = 446
    HELLGATE_STATUS_UPDATE = 447
    HELLGATE_SUSPENSE = 448
    REPLACE_SPELL_SLOT_WITH_MULTI_SPELL = 449
    NEW_CORRUPTED_SHRINE = 450
    UPDATE_CORRUPTED_SHRINE = 451
    CORRUPTED_SHRINE_USAGE_START = 452
    CORRUPTED_SHRINE_USAGE_CANCEL = 453
    EXIT_USED = 454
    LINKED_TO_OBJECT = 455
    LINK_TO_OBJECT_BROKEN = 456
    ESTIMATED_MARKET_VALUE_UPDATE = 457
    STUCK_CANCEL = 458
    DUNGON_ESCAPE_READY = 459
    FACTION_WARFARE_CLUSTER_STATE = 460
    FACTION_WARFARE_HAS_UNCLAIMED_WEEKLY_REPORTS_EVENT = 461
    SIMPLE_FEEDBACK = 462
    SMART_CLUSTER_QUEUE_SKIP_CLUSTER_ERROR = 463
    XIGN_CODE_EVENT = 464
    BATCH_USE_ITEM_START = 465
    BATCH_USE_ITEM_END = 466
    RED_ZONE_EVENT_CLUSTER_STATUS = 467
    RED_ZONE_PLAYER_NOTIFICATION = 468
    RED_ZONE_WORLD_EVENT = 469
    FACTION_WARFARE_STATS = 470
    UPDATE_FACTION_BALANCE_FACTORS = 471
    FACTION_ENLISTMENT_CHANGED = 472
    UPDATE_FACTION_RANK = 473
    FACTION_WARFARE_CAMPAIGN_REWARDS_UNLOCKED = 474
    FEATURED_FEATURE_UPDATE = 475
    NEW_CARRIABLE_OBJECT = 476
    MINIMAP_CRYSTAL_POSITION_MARKER = 477
    CARRIED_OBJECT_UPDATE = 478
    PICKUP_CARRIABLE_OBJECT_START = 479
    PICKUP_CARRIABLE_OBJECT_CANCEL = 480
    PICKUP_CARRIABLE_OBJECT_FINISHED = 481
    DO_SIMPLE_ACTION_START = 482
    DO_SIMPLE_ACTION_CANCEL = 483
    DO_SIMPLE_ACTION_FINISHED = 484
    NOTIFY_GUEST_ACCOUNT_VERIFIED = 485
    MIGHT_AND_FAVOR_RECEIVED_EVENT = 486
    WEEKLY_PVP_CHALLENGE_REWARD_STATE_UPDATE = 487
    NEW_UNLOCKED_PVP_SEASON_CHALLENGE_REWARDS = 488
    STATIC_DUNGEON_ENTRANCES_DUNGEON_EVENT_STATUS_UPDATES = 489
    STATIC_DUNGEON_DUNGEON_VALUE_UPDATE = 490
    STATIC_DUNGEON_ENTRANCE_DUNGEON_EVENTS_ABORTED = 491
    IN_APP_PURCHASE_CONFIRMED_GOOGLE_PLAY = 492
    FEATURE_SWITCH_INFO = 493
    PARTY_JOIN_REQUEST_ABORTED = 494
    PARTY_INVITE_ABORTED = 495
    PARTY_START_HUNT_REQUEST = 496
    PARTY_START_HUNT_REQUESTED = 497
    PARTY_START_HUNT_REQUEST_ANSWER = 498
    PARTY_PLAYER_LEAVE_SCHEDULED = 499
    GUILD_INVITE_DECLINED = 500
    CANCEL_MULTI_SPELL_SLOTS = 501
    NEW_VISUAL_EVENT_OBJECT = 502
    CASTLE_CLAIM_PROGRESS = 503
    CASTLE_CLAIM_PROGRESS_LOGO = 504
    TOWN_PORTAL_UPDATE_STATE = 505
    TOWN_PORTAL_FAILED = 506
    CONSUMABLE_VANITY_CHARGES_ADDED = 507
    FESTIVITIES_UPDATE = 508
    NEW_BANNER_OBJECT = 509
    NEW_MISTS_IMMEDIATE_RETURN_EXIT = 510
    MISTS_PLAYER_JOINED_INFO = 511
    NEW_MISTS_STATIC_ENTRANCE = 512
    NEW_MISTS_OPEN_WORLD_EXIT = 513
    NEW_TUNNEL_EXIT_TEMP = 514
    NEW_MISTS_WISP_SPAWN = 515
    MISTS_WISP_SPAWN_STATE_CHANGE = 516
    NEW_MISTS_CITY_ENTRANCE = 517
    NEW_MISTS_CITY_ROADS_ENTRANCE = 518
    MISTS_CITY_ROADS_ENTRANCE_PARTY_STATE_UPDATE = 519
    MISTS_CITY_ROADS_ENTRANCE_CLEAR_STATE_FOR_PARTY = 520
    MISTS_ENTRANCE_DATA_CHANGED = 521
    NEW_MISTS_CAGED_WISP = 522
    MISTS_WISP_CAGE_OPENED = 523
    MISTS_ENTRANCE_PARTY_BINDING_CREATED = 524
    MISTS_ENTRANCE_PARTY_BINDING_CLEARED = 525
    MISTS_ENTRANCE_PARTY_BINDING_INFOS = 526
    NEW_MISTS_BORDER_EXIT = 527
    NEW_MISTS_DUNGEON_EXIT = 528
    LOCAL_QUEST_INFOS = 529
    LOCAL_QUEST_STARTED = 530
    LOCAL_QUEST_ACTIVE = 531
    LOCAL_QUEST_INACTIVE = 532
    LOCAL_QUEST_PROGRESS_UPDATE = 533
    NEW_UNRESTRICTED_PVP_ZONE = 534
    TEMPORARY_FLAGGING_STATUS_UPDATE = 535
    SPELL_TEST_PERFORMANCE_UPDATE = 536
    TRANSFORMATION = 537
    TRANSFORMATION_END = 538
    UPDATE_TRUSTLEVEL = 539
    REVEAL_HIDDEN_TIME_STAMPS = 540
    MODIFY_ITEM_TRAIT_FINISHED = 541
    REROLL_ITEM_TRAIT_VALUE_FINISHED = 542
    HUNT_QUEST_PROGRESS_INFO = 543
    HUNT_STARTED = 544
    HUNT_FINISHED = 545
    HUNT_ABORTED = 546
    HUNT_MISSION_STEP_STATE_UPDATE = 547
    NEW_HUNT_TRACK = 548
    HUNT_MISSION_UPDATE = 549
    HUNT_QUEST_MISSION_PROGRESS_UPDATE = 550
    HUNT_TRACK_USED = 551
    HUNT_TRACK_USEABLE_AGAIN = 552
    MINIMAP_HUNT_TRACK_MARKERS = 553
    NO_TRACKS_FOUND = 554
    HUNT_QUEST_ABORTED = 555
    INTERACT_WITH_TRACK_START = 556
    INTERACT_WITH_TRACK_CANCEL = 557
    INTERACT_WITH_TRACK_FINISHED = 558
    NEW_DYNAMIC_COMPOUND = 559
    LEGENDARY_ITEM_DESTROYED = 560
    ATTUNEMENT_INFO = 561
    TERRITORY_CLAIM_RAIDED_RAW_ENERGY_CRYSTAL_RESULT = 562
    CARRIED_OBJECT_EXPIRY_WARNING = 563
    CARRIED_OBJECT_EXPIRED = 564
    TERRITORY_RAID_START = 565
    TERRITORY_RAID_CANCEL = 566
    TERRITORY_RAID_FINISHED = 567
    TERRITORY_RAID_RESULT = 568
    TERRITORY_MONOLITH_ACTIVE_RAID_STATUS = 569
    TERRITORY_MONOLITH_ACTIVE_RAID_CANCELLED = 570
    MONOLITH_ENERGY_STORAGE_UPDATE = 571
    MONOLITH_NEXT_SCHEDULED_OPEN_WORLD_ATTACK_UPDATE = 572
    MONOLITH_PROTECTED_BUILDINGS_DAMAGE_REDUCTION_UPDATE = 573
    NEW_BUILDING_BASE_EVENT = 574
    NEW_FORTIFICATION_BUILDING = 575
    NEW_CASTLE_GATE_BUILDING = 576
    BUILDING_DURABILITY_UPDATE = 577
    MONOLITH_FORTIFICATION_POINTS_UPDATE = 578
    FORTIFICATION_BUILDING_UPGRADE_INFO = 579
    FORTIFICATION_BUILDINGS_DAMAGE_STATE_UPDATE = 580
    SIEGE_NOTIFICATION_EVENT = 581
    UPDATE_ENEMY_WAR_BANNER_ACTIVE = 582
    TERRITORY_ANNOUNCE_PLAYER_EJECTION = 583
    CASTLE_GATE_SWITCH_USE_STARTED = 584
    CASTLE_GATE_SWITCH_USE_FINISHED = 585
    FORTIFICATION_BUILDING_WILL_DOWNGRADE = 586
    BOT_COMMAND = 587
    JOURNAL_ACHIEVEMENT_PROGRESS_UPDATE = 588
    JOURNAL_CLAIMABLE_REWARD_UPDATE = 589
    KEY_SYNC = 590
    LOCAL_QUEST_AREA_GONE = 591
    DYNAMIC_TEMPLATE = 592
    DYNAMIC_TEMPLATE_FORCED_STATE_CHANGE = 593
    NEW_OUTLANDS_TELEPORTATION_PORTAL = 594
    NEW_OUTLANDS_TELEPORTATION_RETURN_PORTAL = 595
    OUTLANDS_TELEPORTATION_BINDING_CLEARED = 596
    OUTLANDS_TELEPORTATION_RETURN_PORTAL_UPDATE_EVENT = 597
    PLAYER_USED_OUTLANDS_TELEPORTATION_PORTAL = 598
