*{box-sizing:border-box}:root{font-family:Inter,system-ui,Avenir,Helvetica,Arial,sans-serif;line-height:1.5;font-weight:400;color-scheme:light dark;color:#ffffffde;font-synthesis:none;text-rendering:optimizeLegibility;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}p{margin:0}a{font-weight:500;color:#646cff;text-decoration:inherit}a:hover{color:#535bf2}#root,body{margin:auto;display:flex;flex-direction:column;justify-content:start;align-items:center;min-width:320px;min-height:100vh;color:#fff;width:100%}h1{font-size:2em;line-height:1}button{border-radius:8px;border:1px solid transparent;padding:.6em 1.2em;font-size:1em;font-weight:500;font-family:inherit;background-color:#1a1a1a;cursor:pointer;transition:border-color .25s}button:hover{border-color:#646cff}button:focus,button:focus-visible{outline:4px auto -webkit-focus-ring-color}@media (prefers-color-scheme: light){:root{color:#213547;background-color:#fff}a:hover{color:#747bff}button{background-color:#f9f9f9}}input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}._passed_ifjrf_1{background-color:green}._failed_ifjrf_4{background-color:red}._healthCheckDiv_ifjrf_7{width:1rem;height:1rem;border-radius:1rem}._toolbar_ifjrf_14{display:flex;justify-content:space-between}._data_ifjrf_19{display:flex;gap:1rem;align-items:center}._dmgBar_uvx94_1{background:linear-gradient(135deg,#ff6486,#6486ff);height:6px;border-radius:8px;margin-bottom:2px}._healBar_uvx94_8{background:linear-gradient(135deg,#64ffde,#64ff90);height:2px;border-radius:4px}._dpsContainer_uvx94_14{display:flex;flex-direction:column;justify-content:flex-start;width:100%;gap:4px;box-sizing:content-box;padding:16px}._dpsRow_uvx94_24{display:flex;flex-direction:row;justify-content:space-between;align-items:center}._dpsNumber_uvx94_31{width:128px;text-align:right}._dpsButton_uvx94_36{display:flex;flex-grow:1;gap:1rem}._hidden_uvx94_42{display:none}._player_uvx94_46{flex-grow:1}._checkboxColor_uvx94_50{accent-color:#64d3ff}._dungeonContainer_1kru6_1{border-radius:1rem;width:100%;padding:2rem;display:flex;flex-direction:column;gap:1rem}._tag_1kru6_12{background-color:#64d3ff;padding:0 1rem;border-radius:1rem;color:#0f3c4e;font-weight:700}._stats_1kru6_20{display:flex;flex-direction:row;align-items:start;gap:.5rem}._statRow_1kru6_27{display:flex;flex-direction:row;align-items:start;gap:3rem}._stickToTop_1kru6_34{z-index:10;position:sticky;top:64px;left:0;width:100%;padding:24px 0}@media screen and (max-width: 1000px){._statRow_1kru6_27{width:100%;justify-content:space-between;gap:0}}._container_1ha35_1{display:flex;flex-direction:column;align-items:center;gap:8px;width:100%;gap:1.5rem}._snackbar_1ha35_10{position:fixed;right:64px}._stats_1ha35_15{display:flex;flex-direction:row;align-items:center;gap:.5rem}._options_1ha35_22{display:flex;flex-direction:row;align-items:center;gap:2rem}._row_1ha35_29{display:flex;width:100%;justify-content:space-between;align-items:center}._hidden_1ha35_36{display:none}._column_owxpy_1{width:50%;display:flex;flex-direction:column;gap:16px}._row_owxpy_8{display:flex;gap:40px}._harvest_owxpy_13{display:flex;gap:8px;align-items:center}._statsContainer_owxpy_19{width:100%;display:flex;flex-direction:column;gap:0}
